import { BasicColumn, FormSchema } from '/@/components/Table';
import { h } from 'vue';
import { Switch } from 'ant-design-vue';
import { setRoleStatus } from '/@/api/tigerapi/system';
import { useMessage } from '/@/hooks/web/useMessage';

export const columns: BasicColumn[] = [
  {
    title: '角色名称',
    dataIndex: 'ROLE_DESC',
    width: 200,
  },
  {
    title: '角色值',
    dataIndex: 'ROLE_CODE',
    width: 180,
  },
  //{
  //  title: '排序',
  //  dataIndex: 'orderNo',
  //  width: 50,
  //},
  {
    title: '状态',
    dataIndex: 'IS_ACTIVE',
    width: 120,
    customRender: ({ record }) => {
      if (!Reflect.has(record, 'pendingStatus')) {
        record.pendingStatus = false;
      }
      return h(Switch, {
        checked: record.IS_ACTIVE === 'Y',
        checkedChildren: '已启用',
        unCheckedChildren: '已禁用',
        loading: record.pendingStatus,
        onChange(checked: boolean) {
          const oldStatus = record.IS_ACTIVE;
          record.pendingStatus = true;
          const newStatus = checked ? 'Y' : 'N';
          console.log(10, newStatus);
          const { createMessage } = useMessage();
          record.IS_ACTIVE = newStatus;
          setRoleStatus(record)
            .then(() => {
              createMessage.success(`已成功修改角色状态`);
            })
            .catch(() => {
              createMessage.error('修改角色状态失败');
              record.IS_ACTIVE = oldStatus;
            })
            .finally(() => {
              record.pendingStatus = false;
            });
        },
      });
    },
    editDynamicDisabled: true,
  },
  {
    title: '创建时间',
    dataIndex: 'CREATE_TIME',
    width: 180,
  },
  //{
  //  title: '备注',
  //  dataIndex: 'remark',
  //},
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'ROLE_DESC',
    label: '角色名称',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'IS_ACTIVE',
    label: '状态',
    component: 'Select',
    componentProps: {
      options: [
        { label: '启用', value: 'Y' },
        { label: '停用', value: 'N' },
      ],
    },
    colProps: { span: 8 },
  },
];

const isMenu = (type: number) => type === 0;
const isOrg = (type: number) => type === 1;
const isFty = (type: number) => type === 2;
const isWh = (type: number) => type === 3;
export const formSchema: FormSchema[] = [
  {
    field: 'ROLE_DESC',
    label: '角色名称',
    required: true,
    component: 'Input',
    colProps: {
      span: 24,
    },
  },
  {
    field: 'ROLE_CODE',
    label: '角色值',
    required: true,
    component: 'Input',
    colProps: {
      span: 24,
    },
  },
  {
    field: 'ID',
    label: '角色ID',
    component: 'Input',
    show: false,
    colProps: {
      span: 24,
    },
  },
  {
    field: 'IS_ACTIVE',
    label: '状态',
    component: 'RadioButtonGroup',
    defaultValue: 'N',
    colProps: {
      span: 24,
    },
    componentProps: {
      options: [
        { label: '启用', value: 'Y' },
        { label: '停用', value: 'N' },
      ],
    },
  },
  {
    field: 'DATA_TYPE',
    label: '权限分配',
    component: 'RadioButtonGroup',
    defaultValue: 0,
    componentProps: ({ schema, tableAction, formActionType, formModel }) => {
      return {
        options: [
          { label: '菜单分配', value: 0 },
          { label: '组织分配', value: 1 },
          { label: '工厂分配', value: 2 },
          { label: '仓库分配', value: 3 },
        ],
        onChange: (e) => {},
      };
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    label: ' ',
    field: 'menu',
    slot: 'menu',
    component: 'Input',
    colProps: {
      span: 24,
    },
    ifShow: ({ values }) => isMenu(values.DATA_TYPE),
  },
  {
    label: ' ',
    field: 'org',
    slot: 'org',
    component: 'Input',
    colProps: {
      span: 24,
    },
    ifShow: ({ values }) => isOrg(values.DATA_TYPE),
  },
  {
    label: ' ',
    field: 'fty',
    slot: 'fty',
    component: 'Input',
    colProps: {
      span: 24,
    },
    ifShow: ({ values }) => isFty(values.DATA_TYPE),
  },
  {
    label: ' ',
    field: 'wh',
    slot: 'wh',
    component: 'Input',
    colProps: {
      span: 24,
    },
    ifShow: ({ values }) => isWh(values.DATA_TYPE),
  },
];
